==> qtjambi-sensors-6.5.2-sources.jar: io/qt/sensors/QIRProximitySensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QIRProximitySensor</code></p>
 */
public class QIRProximitySensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QIRProximitySensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QIRProximitySensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QIRProximitySensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code>QIRProximitySensor::<wbr>QIRProximitySensor(QObject*)</code></p>
     */
    public QIRProximitySensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QIRProximitySensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QSensor::<wbr>reading()const</code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QIRProximityReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QIRProximityReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QIRProximitySensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QIRProximitySensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QIRProximitySensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.5.7-sources.jar: io/qt/sensors/QIRProximitySensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QIRProximitySensor</code></p>
 */
public class QIRProximitySensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QIRProximitySensor.class);
    
    
    /**
     * <p>See <code>QIRProximitySensor::<wbr/>QIRProximitySensor(QObject*)</code></p>
     */
    public QIRProximitySensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QIRProximitySensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QSensor::<wbr/>reading()const</code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QIRProximityReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QIRProximityReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QIRProximitySensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QIRProximitySensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QIRProximitySensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QIRProximitySensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QIRProximitySensor() {
        this((io.qt.core.QObject)null);
    }
}
